# qblocal_backup

a local backup tool for qbittorrent without call webui api.

## Usage

``` cmd
python -m qblocal_backup <QBITTORRENT_CONF> <DEST_LOCATION>
```

`<DEST_LOCATION>` should be a directory.
